Crate snap_tun

Crate snap_tun 

SNAP tunnel library.

Modules

cert_validator
Module containing an implementation of a certificate validator.
client
SNAP tunnel client.
metrics
SNAP tunnel metrics.
requests
SNAP tunnel control requests.
server
The server of the SNAPtun protocol.
server_deprecated
The snaptun server.

Structs

AddressAllocation
Address allocation.
AddressAllocationId
Address allocation identifier.

Enums

AddressAllocationError
Address allocation error.

Constants

IPV4_WILDCARD
Placeholder IPv4-Address that should be used by callers to AddressAllocator::allocate if the caller wants to request any of the available IPv4-addresses.
IPV6_WILDCARD
Placeholder IPv6-Address that should be used by callers to AddressAllocator::allocate if the caller wants to request any of the available IPv4-addresses.

Traits

AddressAllocator
Address allocator trait.