pub struct Ed25519ServerCertValidator(pub [u8; 32]);Expand description
Validation only succeeds if the subject’s Ed25519 public key matches the configured public key.
The intended use case is verifying the identity of a remote server for which the public key is known and the server presents a self-signed certificate containing an Ed25519 public key.
Other than the server’s public key, all parameters of the server’s certificate are ignored.
Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Debug for Ed25519ServerCertValidator
impl Debug for Ed25519ServerCertValidator
Sourceimpl ServerCertVerifier for Ed25519ServerCertValidator
impl ServerCertVerifier for Ed25519ServerCertValidator
Sourcefn verify_server_cert(
&self,
end_entity: &CertificateDer<'_>,
_intermediates: &[CertificateDer<'_>],
_server_name: &ServerName<'_>,
_ocsp_response: &[u8],
_now: UnixTime,
) -> Result<ServerCertVerified, Error>
fn verify_server_cert( &self, end_entity: &CertificateDer<'_>, _intermediates: &[CertificateDer<'_>], _server_name: &ServerName<'_>, _ocsp_response: &[u8], _now: UnixTime, ) -> Result<ServerCertVerified, Error>
Verify the end-entity certificate
end_entity is valid for the
hostname dns_name and chains to at least one trust anchor. Read moreSourcefn verify_tls12_signature(
&self,
_message: &[u8],
_cert: &CertificateDer<'_>,
_dss: &DigitallySignedStruct,
) -> Result<HandshakeSignatureValid, Error>
fn verify_tls12_signature( &self, _message: &[u8], _cert: &CertificateDer<'_>, _dss: &DigitallySignedStruct, ) -> Result<HandshakeSignatureValid, Error>
Verify a signature allegedly by the given server certificate. Read more
Sourcefn verify_tls13_signature(
&self,
message: &[u8],
cert: &CertificateDer<'_>,
dss: &DigitallySignedStruct,
) -> Result<HandshakeSignatureValid, Error>
fn verify_tls13_signature( &self, message: &[u8], cert: &CertificateDer<'_>, dss: &DigitallySignedStruct, ) -> Result<HandshakeSignatureValid, Error>
Verify a signature allegedly by the given server certificate. Read more
Sourcefn supported_verify_schemes(&self) -> Vec<SignatureScheme>
fn supported_verify_schemes(&self) -> Vec<SignatureScheme>
Return the list of SignatureSchemes that this verifier will handle,
in
verify_tls12_signature and verify_tls13_signature calls. Read moreSourcefn requires_raw_public_keys(&self) -> bool
fn requires_raw_public_keys(&self) -> bool
Returns whether this verifier requires raw public keys as defined
in RFC 7250.
Sourcefn root_hint_subjects(&self) -> Option<&[DistinguishedName]>
fn root_hint_subjects(&self) -> Option<&[DistinguishedName]>
Return the
DistinguishedNames of certificate authorities that this verifier trusts. Read moreAuto Trait Implementations
impl Freeze for Ed25519ServerCertValidator
impl RefUnwindSafe for Ed25519ServerCertValidator
impl Send for Ed25519ServerCertValidator
impl Sync for Ed25519ServerCertValidator
impl Unpin for Ed25519ServerCertValidator
impl UnsafeUnpin for Ed25519ServerCertValidator
impl UnwindSafe for Ed25519ServerCertValidator