Module client

Module client 

SNAP tunnel client.

Structs

SnapTunEndpoint
Snap tunnel endpoint that allows creating new snap tun connections. It holds one static identity and manages the registration of this identity with all connected control planes.
SnapTunnel
A SNAP tunnel connection.

Enums

ConnectSnapTunSocketError
Error when connecting to a SNAP tunnel.
SnapTunnelDriverError
Error when sending or receiving packets on the SNAP tunnel.
SnapTunnelReceiveError
Error when receiving a packet from the SNAP tunnel connection.

Constants

PACKET_BUF_POOL_SIZE
Size of the packet buffer pool used for SNAP tunnels. This represents the maximum packet size that can be handled.
PERSISTENT_KEEPALIVE_SECONDS
Use a default value of 10 seconds for Persistent keepalive seconds for SNAP tunnels. This should be short enough to keep NAT mappings alive.

Traits

SnapTunControlPlaneClient
Trait for a control plane client.