update_token

Function update_token 

pub async fn update_token(
    conn: &Connection,
    token: &str,
) -> Result<SystemTime, ControlError>
Update SNAP token.

This opens a new bi-directional stream to the server, sends a update SNAP token request, and waits for the response. On success, it returns the new token expiry time.