ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
SNAP tunnel client builder.

Implementations

Source

impl ClientBuilder

pub fn new<S: AsRef<str>>(initial_session_token: S) -> Self

Client builder with an initial session token to be used to authenticate requests.

pub fn with_desired_addresses(self, desired_addresses: Vec<EndhostAddr>) -> Self

Set the desired addresses to be requested from the SNAP. If empty, the SNAP server will assign an address.

pub fn with_auto_session_renewal( self, session_renewal: AutoSessionRenewal, ) -> Self

Enable automatic session renewal.

pub async fn connect( self, conn: Connection, ) -> Result<(Sender, Receiver, Control), SnapTunError>

Establish a SNAP tunnel using the provided QUIC connection using the builder’s settings.