pub struct Control { /* private fields */ }Expand description
Control can be used to send control messages to the server
Implementations
Sourceimpl Control
impl Control
Sourcepub fn assigned_sock_addr(&self) -> Option<SocketAddr>
pub fn assigned_sock_addr(&self) -> Option<SocketAddr>
Returns the socket address assigned by the server. This typically corresponds to the client’s remote socket address; i.e. the possibly NAT’ed address of the client visible to the server.
It is up to the client to use the correct ISD-AS for this tunnel.
Sourcepub fn token_expiry(&self) -> SystemTime
pub fn token_expiry(&self) -> SystemTime
Returns the token expiry time.
Sourcepub fn snap_token(&self) -> String
pub fn snap_token(&self) -> String
Returns the current SNAP token.
Sourcepub async fn update_token(&mut self) -> Result<(), ControlError>
pub async fn update_token(&mut self) -> Result<(), ControlError>
Sends a new SNAP token to keep the snaptun connection with the server established.
Sourcepub async fn closed(&self) -> ConnectionError
pub async fn closed(&self) -> ConnectionError
An async function that returns when the underlying connection is closed.
Sourcepub fn inner_conn(&self) -> Connection
pub fn inner_conn(&self) -> Connection
Returns the underlying QUIC connection.
Sourcepub fn debug_path_stats(&self) -> impl Debug + 'static + use<>
pub fn debug_path_stats(&self) -> impl Debug + 'static + use<>
This is a helper function that returns a debug-printable object containing metrics about the underlying QUIC-connection.