pub struct SnapTunEndpoint { /* private fields */ }Expand description
Snap tunnel endpoint that allows creating new snap tun connections. It holds one static identity and manages the registration of this identity with all connected control planes.
Implementations
Sourceimpl SnapTunEndpoint
impl SnapTunEndpoint
Sourcepub fn new(
token_source: Arc<dyn TokenSource>,
static_private: StaticSecret,
) -> Self
pub fn new( token_source: Arc<dyn TokenSource>, static_private: StaticSecret, ) -> Self
Creates a new SNAP tunnel socket manager.
Sourcepub async fn connect_tunnel(
&self,
peer_public: PublicKey,
dataplane_address: SocketAddr,
control_plane: Url,
control_plane_client: Arc<dyn SnapTunControlPlaneClient>,
underlay_socket: Arc<UdpSocket>,
receive_queue_capacity: usize,
pool: PacketBufPool<PACKET_BUF_POOL_SIZE>,
) -> Result<SnapTunnel, ConnectSnapTunSocketError>
pub async fn connect_tunnel( &self, peer_public: PublicKey, dataplane_address: SocketAddr, control_plane: Url, control_plane_client: Arc<dyn SnapTunControlPlaneClient>, underlay_socket: Arc<UdpSocket>, receive_queue_capacity: usize, pool: PacketBufPool<PACKET_BUF_POOL_SIZE>, ) -> Result<SnapTunnel, ConnectSnapTunSocketError>
Connects a new SNAP tunnel. If the endpoints static identity is not already registered with the selected snap-tun control plane, it is registered before this method returns.