SnapTunNgSocket

Struct SnapTunNgSocket 

pub struct SnapTunNgSocket { /* private fields */ }
A SNAP tun ng socket.

Implementations

Source

impl SnapTunNgSocket

pub async fn new( static_private: StaticSecret, peer_public: PublicKey, underlay_socket: Arc<UdpSocket>, dataplane_address: SocketAddr, receive_queue_capacity: usize, ) -> Result<Self, SnapTunNgSocketError>

Creates a new SNAP tunnel and waits for the handshake to complete.

Arguments
  • static_private - The client’s static private key
  • peer_public - The server’s static public key (needed for handshake)
  • rate_limiter - Rate limiter for the tunnel
  • underlay_socket - UDP socket for sending/receiving packets
  • dataplane_address - Address of the remote server
  • receive_queue_capacity - Capacity of the receive queue
pub async fn send(&self, payload: BytesMut) -> Result<()>

Send a packet to the remote server.

pub fn try_send(&self, payload: BytesMut) -> Result<()>

Try to send a packet to the remote server. Returns error of try_send_to.

pub async fn recv(&self) -> Result<Bytes, SnapTunNgSocketError>

Receive a packet from the remote server.

pub fn poll_recv( &self, cx: &mut Context<'_>, ) -> Poll<Result<Bytes, SnapTunNgSocketError>>

Poll for a packet from the remote server.

pub fn local_addr(&self) -> SocketAddr

Get the local socket address. Assigned by the remote server.

pub async fn writable(&self) -> Result<()>

Check if the socket is writable.