TunnelStateMachine

Struct TunnelStateMachine 

pub struct TunnelStateMachine<T: SnapTunToken> { /* private fields */ }
The state transitions of an edgetun connection.

Unassigned --> Assigend --> Closed

Once the connection is closed, it remains closed. The state machine has an internal state version that is incremented whenever the state changes. This can be used to cheaply detect changes in the state machine from the outside.