Sender

Struct Sender 

pub struct Sender<T: SnapTunToken> { /* private fields */ }
Sender can be used to send packets to the client. It is returned by Server::accept_with_timeout.

Sender offers a synchronous and an asychronous API to send packets to the client.

Implementations

Source

impl<T: SnapTunToken> Sender<T>

pub fn assigned_addresses(&self) -> Vec<EndhostAddr>

Returns the addresses assigned to this sender.

pub fn assigned_socket_addr(&self) -> Option<SocketAddr>

Returns the endhost socket address assigned to the endhost.

pub fn remote_underlay_address(&self) -> SocketAddr

Returns the remote address of the underlying QUIC connection.

pub fn send(&self, pkt: Bytes) -> Result<(), SendPacketError<T>>

Send a packet to the client. The packet needs to fit entirely into a QUIC datagram.

Errors

The function returns an error if either the connection is in an erroneous state (non-recoverable), or the address assignment has changed. In the latter case, SendPacketError::NewAssignedAddress is returned with a new Sender object that is assigned the new address. The old object will return a SendPacketError::ConnectionClosed error.

pub async fn send_wait(&self, pkt: Bytes) -> Result<(), SendPacketError<T>>

Send a packet to the client. The packet needs to fit entirely into a QUIC datagram.

Unlike Self::send, this method will wait for buffer space during congestion conditions, which effectively prioritizes old datagrams over new datagrams.

pub fn close(&self, error_code: SnaptunConnErrors, reason: &[u8])

Immediately closes the underlying connection with the given code and reason.

All other methods on this Sender will return ConnectionClosed after this is called.