pub struct Server<T> { /* private fields */ }Expand description
The snaptun server accepts connections from clients and provides them with an address assignment.
Implementations
Sourceimpl<T: SnapTunToken> Server<T>
impl<T: SnapTunToken> Server<T>
Sourcepub fn new(validator: Arc<dyn TokenValidator<T>>, metrics: Metrics) -> Self
pub fn new(validator: Arc<dyn TokenValidator<T>>, metrics: Metrics) -> Self
Create a new server that can accept QUIC connections and turn them into snap tunnels.
Sourcepub async fn accept_with_timeout(
&self,
conn: Connection,
) -> Result<(Sender<T>, Receiver<T>, Control), AcceptError>
pub async fn accept_with_timeout( &self, conn: Connection, ) -> Result<(Sender<T>, Receiver<T>, Control), AcceptError>
Accept a connection and establish a tunnel.
Tunnel initialization
The client is expected to first send a token update request, followed by an address assignment request. The connection is closed with a SnaptunConnErrors::Timeout if the client does not send the requests within ACCEPT_TIMEOUT.