pub enum QueuePacketError {
Full {
packet: Packet,
target: SocketAddr,
},
PacketTooLarge {
packet: Packet,
target: SocketAddr,
packet_len: usize,
max_packet_size: usize,
},
}Expand description
Errors returned while queueing packets for batched transmission.
Variants
Full
The sender queue is full and cannot accept another packet right now.
Fields

target: SocketAddrThe original target address of the unsent packet.
PacketTooLarge
The packet is larger than the configured sender scratch budget.