SNAP tunnel library.
Modules
- cert_
validator - Module containing an implementation of a certificate validator.
- client
- SNAP tunnel client.
- metrics
- SNAP tunnel metrics.
- requests
- SNAP tunnel control requests.
- server
- The server of the SNAPtun protocol.
- server_
deprecated - The snaptun server.
Structs
- Address
Allocation - Address allocation.
- Address
Allocation Id - Address allocation identifier.
Enums
- Address
Allocation Error - Address allocation error.
Constants
- IPV4_
WILDCARD - Placeholder IPv4-Address that should be used by callers to AddressAllocator::allocate if the caller wants to request any of the available IPv4-addresses.
- IPV6_
WILDCARD - Placeholder IPv6-Address that should be used by callers to AddressAllocator::allocate if the caller wants to request any of the available IPv4-addresses.
Traits
- Address
Allocator - Address allocator trait.