Module client

Module client 

SNAP tunnel client.

Structs

ClientBuilder
SNAP tunnel client builder.
Control
Control can be used to send control messages to the server
Receiver
SNAP tunnel receiver.
Sender
SNAP tunnel sender.

Enums

AddrAssignError
Address assignment error.
ControlError
SNAP tunnel control errors.
ParseResponseError
Parse response error.
RenewTaskError
Token renew task error.
SendControlRequestError
Send control request error.
SnapTunError
SNAP tunnel errors.

Constants

MAX_CTRL_MESSAGE_SIZE
Maximum size of a control message, both request and response.

Functions

update_token
Update SNAP token.