SNAP tunnel client.
Structs
- Client
Builder - SNAP tunnel client builder.
- Control
- Control can be used to send control messages to the server
- Receiver
- SNAP tunnel receiver.
- Sender
- SNAP tunnel sender.
Enums
- Addr
Assign Error - Address assignment error.
- Control
Error - SNAP tunnel control errors.
- Parse
Response Error - Parse response error.
- Renew
Task Error - Token renew task error.
- Send
Control Request Error - Send control request error.
- Snap
TunError - SNAP tunnel errors.
Constants
- MAX_
CTRL_ MESSAGE_ SIZE - Maximum size of a control message, both request and response.
Functions
- update_
token - Update SNAP token.