SNAP tunnel client.
Structs
- Auto
Session Renewal - Automatic session renewal configuration.
- Client
Builder - SNAP tunnel client builder.
- Control
- Control can be used to send control messages to the server
- Receiver
- SNAP tunnel receiver.
- Sender
- SNAP tunnel sender.
Enums
- Addr
Assign Error - Address assignment error.
- Control
Error - SNAP tunnel control errors.
- Parse
Response Error - Parse response error.
- Renew
Task Error - Token renew task error.
- Send
Control Request Error - Send control request error.
- Snap
TunError - SNAP tunnel errors.
Constants
- CTRL_
RESPONSE_ BUF_ SIZE - All control requests issued by the client MUST NOT exceed
CTRL_REQUEST_BUF_SIZEbytes. - DEFAULT_
RENEWAL_ WAIT_ THRESHOLD - Lead time for session renewal. Renewal is triggered when the current time is later than the token expiry minus the lead time.
Functions
- renew_
session - Renew SNAP tunnel session.
Type Aliases
- Token
Renew Error - Token renewal error.
- Token
Renew Fn - Function type for renewing tokens.