pub enum SnapTunnelDriverError {
SendIoError(Error),
ReceiveIoError(Error),
ReceiveQueueClosed,
ConnectionExpired,
WireguardError(WireGuardError),
}Expand description
Error when sending or receiving packets on the SNAP tunnel.
Variants
SendIoError(Error)
I/O error when sending packets on the underlay socket.
ReceiveIoError(Error)
I/O error when receiving packets on the underlay socket.
ReceiveQueueClosed
Receive queue closed.
ConnectionExpired
Connection expired.
WireguardError(WireGuardError)
Error receiving a Wireguard packet. This will never be WireGuardError::ConnectionExpired.