pub async fn renew_session(
conn: &Connection,
token: &str,
) -> Result<SystemTime, ControlError>Expand description
Renew SNAP tunnel session.
This opens a new bi-directional stream to the server, sends a session renewal request, and waits for the response. On success, it returns the new session expiry time.