pub struct Control { /* private fields */ }Expand description
Control can be used to send control messages to the server
Implementations
Sourceimpl Control
impl Control
Sourcepub fn assigned_addresses(&self) -> Vec<EndhostAddr>
pub fn assigned_addresses(&self) -> Vec<EndhostAddr>
Returns the currently assigned addresses.
Sourcepub fn session_expiry(&self) -> SystemTime
pub fn session_expiry(&self) -> SystemTime
Returns the session expiry time.
Sourcepub async fn renew_session(&mut self) -> Result<(), ControlError>
pub async fn renew_session(&mut self) -> Result<(), ControlError>
Sends a session renewal request to the snaptun server.