pub struct SnapTunNgSocket { /* private fields */ }Expand description
A SNAP tun ng socket.
Implementations
Sourceimpl SnapTunNgSocket
impl SnapTunNgSocket
Sourcepub async fn new(
static_private: StaticSecret,
peer_public: PublicKey,
underlay_socket: Arc<UdpSocket>,
dataplane_address: SocketAddr,
receive_queue_capacity: usize,
) -> Result<Self, SnapTunNgSocketError>
pub async fn new( static_private: StaticSecret, peer_public: PublicKey, underlay_socket: Arc<UdpSocket>, dataplane_address: SocketAddr, receive_queue_capacity: usize, ) -> Result<Self, SnapTunNgSocketError>
Creates a new SNAP tunnel and waits for the handshake to complete.
Arguments
static_private- The client’s static private keypeer_public- The server’s static public key (needed for handshake)rate_limiter- Rate limiter for the tunnelunderlay_socket- UDP socket for sending/receiving packetsdataplane_address- Address of the remote serverreceive_queue_capacity- Capacity of the receive queue
Sourcepub fn try_send(&self, payload: BytesMut) -> Result<()>
pub fn try_send(&self, payload: BytesMut) -> Result<()>
Try to send a packet to the remote server. Returns error of try_send_to.
Sourcepub async fn recv(&self) -> Result<Bytes, SnapTunNgSocketError>
pub async fn recv(&self) -> Result<Bytes, SnapTunNgSocketError>
Receive a packet from the remote server.
Sourcepub fn poll_recv(
&self,
cx: &mut Context<'_>,
) -> Poll<Result<Bytes, SnapTunNgSocketError>>
pub fn poll_recv( &self, cx: &mut Context<'_>, ) -> Poll<Result<Bytes, SnapTunNgSocketError>>
Poll for a packet from the remote server.
Sourcepub fn local_addr(&self) -> SocketAddr
pub fn local_addr(&self) -> SocketAddr
Get the local socket address. Assigned by the remote server.