Module server

Module server 

The server of the SNAPtun protocol.

As the underlying protocol is symmetric (both peers can act as initiator/responders that establish a session), technically, there is no server. The term “server” here just refers to and endpoint that manages multiple peers.

Structs

HandleOutgoingPacketResult
Packet-processing output for callers that need the active session once an outbound payload is accepted into the tunnel pipeline.
SnapTunServer
The SnapTunServer manages one Tunn per remote socket address.

Enums

HandleIncomingPacketResult
Packet-processing output for callers that also need the resolved tunnel session.

Traits

SnapTunAuthorization
Authorization layer for the snaptun server.