pub struct TunnelStateMachine<T: SnapTunToken> { /* private fields */ }Expand description
The state transitions of an edgetun connection.
Unassigned --> Assigend --> ClosedOnce the connection is closed, it remains closed. The state machine has an internal state version that is incremented whenever the state changes. This can be used to cheaply detect changes in the state machine from the outside.